#
# spec file for package unifdef
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           unifdef
Summary:        Removes ifdefs from C files
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Version:        2.12
Release:        bp155.3.8
URL:            https://dotat.at/prog/unifdef/
Source:         https://dotat.at/prog/unifdef/unifdef-%{version}.tar.xz
Patch0:         fix-fgets-.-size-1.patch
BuildRequires:  xz

%description
Unifdef is useful for removing ifdef'ed lines from a file while otherwise
leaving the file alone.  Unifdef acts on #ifdef, #ifndef, #else, and #endif
lines, and it knows only enough about C to know when one of these is
inactive because it is inside a comment, or a single or double quote.

%prep
%autosetup -p1
sed -i Makefile \
	-e 's,^\(prefix\).*=.*,\1 =\t%{_prefix},' \
	-e 's,^\(bindir\).*=.*,\1 =\t%{_bindir},' \
	-e 's,^\(mandir\).*=.*,\1 =\t%{_mandir},'

%build
make CFLAGS="%optflags"

%check
make test

%install
%{?make_install} %{!?make_install:make install DESTDIR=%{buildroot}}

%files
%license COPYING
%doc Changelog README
%{_bindir}/unifdef
%{_bindir}/unifdefall
%{_mandir}/man1/unifdef.1*
%{_mandir}/man1/unifdefall.1*

%changelog
* Wed Aug 10 2022 Martin Liška <mliska@suse.cz>
- Add fix-fgets-.-size-1.patch that fixes broken package
  (https://github.com/fanf2/unifdef/pull/15).
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 2.12:
  * man: note incomplete C++ raw string literal support
  * C++11 raw string literal support
  * doc: clarify where to send bug reports
  * unifdef.1: clarify backslash-newline behaviour in DESCRIPTION
  * unifdef: more fixes for weird whitespace
  * portability: fix problems compiling with C++ compiler
  * Avoid -Wmissing-initializer
  * man: use .Mt to mark up email addresses
* Fri Dec  4 2015 sweet_f_a@gmx.de
- Update to 2.11:
  * bug fixes
  * add support for additional #if/#elif operators
  * improve portability to Windows
* Tue Feb 25 2014 sweet_f_a@gmx.de
- Update to 2.10:
  * fix a bug in the -f option's support for #undef directives
  * improve portability to Windows
* Mon Jun 10 2013 pth@suse.de
- Update to 2.9:
  * further debugging improvements
  * improve indirect macro definitions
  * Note in the debug output when a macro value is updated.
  * Do not change a macro from defined to undefined.
  * Recursive definitions no longer cause a loop.
  * support for simple macro value indirection
* Mon May  6 2013 sweet_f_a@gmx.de
- update to 2.8:
  * read #define and #undef preprocessor directives from auxiliary
    header-like files given with the -f command line option.
  * you can use -f instead of or in addition to the -D and -U options
  * test suite fixes
- remove unifdef-2.7-tests-fix-multimissing.sh.patch
- fix broken (out-commented) rpm description text
* Tue Apr  2 2013 sweet_f_a@gmx.de
- update to 2.7:
  * process multiple files with one invocation
  * include filenames on #line directives when appropriate.
  * experimental support for Windows, feedback from Windows
    developers is welcome
  * various bug fixes
- add unifdef-2.7-tests-fix-multimissing.sh.patch
* Mon Jan 16 2012 sweet_f_a@gmx.de
- update to 2.6 using the latest fork of the original NetBSD
  project
- license changed to BSD-2-Clause
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Feb 16 2007 pth@suse.de
- Redo cleanup patch to get unifdef working again.
* Fri Sep 29 2006 pth@suse.de
- Remove nasm from BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov  7 2005 pth@suse.de
- Fix defattr
* Sat Nov  5 2005 dmueller@suse.de
- fix filelist
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Fri Jan  7 2005 pth@suse.de
- Initial package creation
- clean up the code.
- autoconfiscate the package
